import sqlite3
from contextlib import contextmanager
from pathlib import Path
from typing import Generator

from palabros.errors import DatabaseError

_APP_PATH = Path.home().joinpath(".palabros")
_DB_PATH = _APP_PATH.joinpath("games.db")


@contextmanager
def db_cursor() -> Generator[sqlite3.Cursor, None, None]:

    """
    Create a cursor to interact with the database.

    Yields:
        An instance of `sqlite3.Cursor`.

    Raises:
        DatabaseError: if any error occurred while working with the database.
    """

    try:
        with sqlite3.connect(str(_DB_PATH), isolation_level=None) as conn:
            conn.row_factory = sqlite3.Row
            cur = conn.cursor()
            yield cur
    except sqlite3.DatabaseError as err:
        raise DatabaseError(str(err)) from err


def init() -> None:

    """
    Initialize the database.
    """

    if not _APP_PATH.exists():
        _APP_PATH.mkdir(parents=True, exist_ok=True)

    if not _DB_PATH.exists():
        with db_cursor() as cur:
            cur.executescript(
                """
                CREATE TABLE IF NOT EXISTS words (
                    word TEXT NOT NULL,
                    PRIMARY KEY (word)
                );

                CREATE TABLE IF NOT EXISTS games (
                    id INTEGER NOT NULL,
                    word TEXT NOT NULL,
                    date TEXT NOT NULL,
                    PRIMARY KEY (id),
                    FOREIGN KEY (word) REFERENCES words (word)
                );

                CREATE UNIQUE INDEX IF NOT EXISTS idx_games_date ON games (date);

                CREATE TABLE IF NOT EXISTS attempts (
                    id INTEGER NOT NULL,
                    game_id INTEGER NOT NULL,
                    word TEXT NOT NULL,
                    match INTEGER NOT NULL,
                    PRIMARY KEY (id),
                    FOREIGN KEY (game_id) REFERENCES games (id)
                );

                INSERT OR IGNORE INTO words (word) VALUES
                    ('abadi'), ('abasi'), ('alaui'), ('argel'), ('aucas'), ('bases'), ('bogas'), ('bozal'),
                    ('burka'), ('cabos'), ('canas'), ('chapa'), ('chota'), ('clave'), ('colla'), ('corno'),
                    ('doble'), ('eones'), ('espia'), ('extra'), ('fagot'), ('figle'), ('gaita'), ('guias'),
                    ('guiri'), ('hippy'), ('ilota'), ('jefes'), ('jetas'), ('joven'), ('lider'), ('manos'),
                    ('maula'), ('moche'), ('nobel'), ('oboes'), ('okupa'), ('orate'), ('oreja'), ('paria'),
                    ('patas'), ('pelma'), ('pobre'), ('poeta'), ('posma'), ('radio'), ('ratas'), ('roñas'),
                    ('tiple'), ('topes'), ('trepa'), ('tusas'), ('viola'), ('vocal'), ('zombi'), ('zopas'),
                    ('acimo'), ('arije'), ('azimo'), ('balde'), ('banda'), ('berbi'), ('bolar'), ('bolos'),
                    ('borne'), ('boyas'), ('brios'), ('buzos'), ('cacao'), ('cajas'), ('cajel'), ('campa'),
                    ('cande'), ('candi'), ('chita'), ('coral'), ('corda'), ('coros'), ('cuche'), ('cural'),
                    ('dares'), ('datas'), ('dente'), ('diado'), ('erres'), ('fases'), ('force'), ('gatas'),
                    ('gibao'), ('groso'), ('janes'), ('jimen'), ('leñas'), ('ligio'), ('lipes'), ('lipis'),
                    ('logis'), ('mache'), ('manta'), ('mores'), ('mueso'), ('najas'), ('niego'), ('oiles'),
                    ('ollar'), ('oques'), ('pises'), ('pudio'), ('ramas'), ('renil'), ('reoca'), ('reojo'),
                    ('ronza'), ('socas'), ('sovoz'), ('sueco'), ('tatas'), ('tenes'), ('tonca'), ('verga'),
                    ('verge'), ('verso'), ('vilos'), ('vises'), ('ababa'), ('abada'), ('abeja'), ('abras'),
                    ('aceña'), ('acera'), ('actas'), ('actea'), ('aftas'), ('agata'), ('agora'), ('aguas'),
                    ('aguja'), ('ajada'), ('alaga'), ('albas'), ('alcas'), ('alcea'), ('aldea'), ('aleda'),
                    ('aleja'), ('aleta'), ('aleya'), ('alfas'), ('algas'), ('almas'), ('aloja'), ('alosa'),
                    ('altas'), ('altea'), ('alula'), ('alzas'), ('ameba'), ('amias'), ('amiba'), ('amida'),
                    ('ancas'), ('ancha'), ('ancla'), ('andas'), ('aneas'), ('anima'), ('ansia'), ('antas'),
                    ('antia'), ('añada'), ('aorta'), ('apnea'), ('arana'), ('araña'), ('arcas'), ('archa'),
                    ('areas'), ('areca'), ('arena'), ('arias'), ('armas'), ('arnas'), ('arpas'), ('arpia'),
                    ('arria'), ('ascas'), ('ascua'), ('asmas'), ('asnas'), ('aspas'), ('astas'), ('atona'),
                    ('aulas'), ('auras'), ('axila'), ('azada'), ('babas'), ('bacas'), ('bacia'), ('badea'),
                    ('bagas'), ('bahia'), ('baila'), ('bajas'), ('balas'), ('balda'), ('balsa'), ('bamba'),
                    ('banca'), ('banas'), ('barba'), ('barca'), ('barda'), ('baria'), ('barra'), ('basas'),
                    ('basca'), ('basta'), ('batas'), ('batea'), ('bauza'), ('bayas'), ('bazas'), ('becas'),
                    ('berma'), ('berza'), ('betas'), ('bicha'), ('bicis'), ('biela'), ('bigas'), ('bilis'),
                    ('billa'), ('bimba'), ('binza'), ('birra'), ('bitas'), ('bizma'), ('bloca'), ('blusa'),
                    ('bocas'), ('bocha'), ('bodas'), ('bofia'), ('boina'), ('boira'), ('bolas'), ('bolsa'),
                    ('bomba'), ('bonga'), ('borda'), ('borla'), ('borra'), ('bosta'), ('botas'), ('bozas'),
                    ('braga'), ('brama'), ('brasa'), ('braza'), ('breas'), ('breca'), ('brega'), ('breva'),
                    ('briba'), ('brida'), ('brisa'), ('broca'), ('broma'), ('brota'), ('broza'), ('bruma'),
                    ('bruta'), ('bubas'), ('budas'), ('buena'), ('bufas'), ('bujia'), ('bulas'), ('bulla'),
                    ('burda'), ('burga'), ('burla'), ('burra'), ('busca'), ('cabra'), ('cacas'), ('cacha'),
                    ('calas'), ('calca'), ('calda'), ('calle'), ('calma'), ('cales'), ('calva'), ('calza'),
                    ('camas'), ('camba'), ('canoa'), ('cañas'), ('capas'), ('capea'), ('cappa'), ('caras'),
                    ('carca'), ('carda'), ('carga'), ('carla'), ('carne'), ('carpa'), ('carta'), ('casas'),
                    ('casca'), ('casia'), ('caspa'), ('casta'), ('catas'), ('cauda'), ('causa'), ('cavas'),
                    ('cazas'), ('cebas'), ('cebra'), ('cecas'), ('cedas'), ('ceiba'), ('cejas'), ('celda'),
                    ('celia'), ('cella'), ('cenas'), ('cenia'), ('cepas'), ('ceras'), ('cerca'), ('cerda'),
                    ('cerna'), ('cerra'), ('cesta'), ('chica'), ('china'), ('choca'), ('chola'), ('chopa'),
                    ('chova'), ('choza'), ('chufa'), ('chupa'), ('cidra'), ('cifra'), ('cilla'), ('cimas'),
                    ('cinca'), ('cinta'), ('circe'), ('cista'), ('citas'), ('clara'), ('clase'), ('clava'),
                    ('cobas'), ('cobra'), ('cocas'), ('cocha'), ('codas'), ('cofas'), ('cofia'), ('cojas'),
                    ('colas'), ('coles'), ('colza'), ('comas'), ('comba'), ('conga'), ('copas'), ('copia'),
                    ('copla'), ('corte'), ('corva'), ('corza'), ('cosas'), ('costa'), ('cotas'), ('coxas'),
                    ('cozes'), ('creas'), ('crema'), ('cresa'), ('creta'), ('crias'), ('criba'), ('cruda'),
                    ('cubas'), ('cucas'), ('cueca'), ('cuera'), ('cueva'), ('cueza'), ('cuida'), ('cuita'),
                    ('cujas'), ('culpa'), ('cunas'), ('cuñas'), ('cuota'), ('curda'), ('curia'), ('curva'),
                    ('dagas'), ('dalas'), ('dalia'), ('damas'), ('danza'), ('debla'), ('dejas'), ('delga'),
                    ('demos'), ('desga'), ('deuda'), ('diada'), ('diana'), ('dicha'), ('dieta'), ('dijes'),
                    ('dinas'), ('diosa'), ('ditas'), ('diuca'), ('divas'), ('dobla'), ('docas'), ('domas'),
                    ('donas'), ('doñas'), ('dosis'), ('draba'), ('driza'), ('droga'), ('drupa'), ('drusa'),
                    ('dubas'), ('ducha'), ('dudas'), ('duela'), ('dueña'), ('dulas'), ('dulia'), ('dumas'),
                    ('dunas'), ('dupla'), ('duras'), ('egida'), ('elite'), ('elite'), ('elles'), ('encia'),
                    ('eneas'), ('epoca'), ('equis'), ('erala'), ('erina'), ('escas'), ('escoa'), ('espia'),
                    ('etapa'), ('etica'), ('etnia'), ('fabla'), ('facas'), ('facha'), ('faena'), ('fajas'),
                    ('falda'), ('falla'), ('falsa'), ('falta'), ('famas'), ('faras'), ('farda'), ('farra'),
                    ('farsa'), ('fauna'), ('fazes'), ('fecha'), ('felpa'), ('feria'), ('festa'), ('fibra'),
                    ('ficha'), ('fiera'), ('fijas'), ('filas'), ('filfa'), ('filia'), ('finca'), ('finta'),
                    ('firma'), ('fisga'), ('flama'), ('flema'), ('flora'), ('flota'), ('fobia'), ('focas'),
                    ('focha'), ('fojas'), ('fonda'), ('forja'), ('forma'), ('fosas'), ('fosca'), ('fotos'),
                    ('fovea'), ('fraga'), ('frase'), ('fresa'), ('freza'), ('frias'), ('frisa'), ('frita'),
                    ('fruta'), ('fugas'), ('fuina'), ('funda'), ('furia'), ('fusas'), ('fusta'), ('gacha'),
                    ('galas'), ('galea'), ('galla'), ('gamas'), ('gamba'), ('gamma'), ('ganas'), ('ganga'),
                    ('gansa'), ('garfa'), ('garla'), ('garra'), ('garza'), ('gasas'), ('gavia'), ('gayas'),
                    ('gazas'), ('gemas'), ('gente'), ('geoda'), ('gesta'), ('gibas'), ('gigas'), ('giras'),
                    ('gleba'), ('glosa'), ('gocha'), ('golas'), ('golfa'), ('gomas'), ('gorda'), ('gorja'),
                    ('gorra'), ('gotas'), ('grada'), ('graja'), ('grama'), ('grana'), ('grapa'), ('grasa'),
                    ('grata'), ('grava'), ('greba'), ('greca'), ('greda'), ('greña'), ('grifa'), ('grima'),
                    ('gripe'), ('grita'), ('gruas'), ('grupa'), ('gruta'), ('guaca'), ('guasa'), ('guata'),
                    ('gubia'), ('guija'), ('guira'), ('guisa'), ('gulas'), ('guras'), ('guzla'), ('habas'),
                    ('habla'), ('hacas'), ('hache'), ('hacha'), ('hadas'), ('halda'), ('hamez'), ('hampa'),
                    ('harca'), ('harma'), ('harpa'), ('hayas'), ('hazes'), ('hazas'), ('hebra'), ('hecha'),
                    ('heria'), ('hevea'), ('hezes'), ('hidra'), ('hiena'), ('higas'), ('hilas'), ('hisca'),
                    ('hojas'), ('honda'), ('honra'), ('horas'), ('horca'), ('horda'), ('horma'), ('hoyas'),
                    ('hozes'), ('hucha'), ('hueca'), ('huesa'), ('huida'), ('hulla'), ('hupes'), ('huras'),
                    ('hutas'), ('hutia'), ('ideas'), ('ijada'), ('imada'), ('imela'), ('ingle'), ('iotas'),
                    ('iride'), ('isbas'), ('islas'), ('itria'), ('jacas'), ('jaiba'), ('jalda'), ('jalea'),
                    ('jalma'), ('jamba'), ('jaras'), ('jarra'), ('jatas'), ('jauja'), ('jaula'), ('jefas'),
                    ('jeras'), ('jerga'), ('jerpa'), ('jibia'), ('jifas'), ('jifia'), ('jigas'), ('jimia'),
                    ('jiras'), ('jisca'), ('josas'), ('jotas'), ('joyas'), ('jubas'), ('judia'), ('jueza'),
                    ('junta'), ('juras'), ('justa'), ('jutas'), ('juvia'), ('kappa'), ('labia'), ('labor'),
                    ('labra'), ('lacas'), ('lacha'), ('ladas'), ('ladra'), ('ladys'), ('lajas'), ('lamas'),
                    ('lamia'), ('lanas'), ('lande'), ('landa'), ('langa'), ('lanza'), ('lapas'), ('larda'),
                    ('larga'), ('larva'), ('lasca'), ('latas'), ('launa'), ('lavas'), ('leche'), ('legas'),
                    ('legua'), ('leida'), ('leila'), ('lejia'), ('lenas'), ('leona'), ('lepra'), ('leras'),
                    ('lerda'), ('lesna'), ('letra'), ('levas'), ('leyes'), ('lezda'), ('lezna'), ('liana'),
                    ('liaza'), ('libra'), ('lidia'), ('lides'), ('ligas'), ('lijas'), ('lilac'), ('lilas'),
                    ('limas'), ('linea'), ('linfa'), ('liñas'), ('liras'), ('liria'), ('lisis'), ('lista'),
                    ('litis'), ('lizas'), ('llaca'), ('llaga'), ('llama'), ('llana'), ('llave'), ('llena'),
                    ('llera'), ('lleva'), ('lobas'), ('locas'), ('locha'), ('logia'), ('loica'), ('loina'),
                    ('lomas'), ('lonas'), ('longa'), ('lonja'), ('loras'), ('lorza'), ('losas'), ('lozas'),
                    ('lucha'), ('luisa'), ('lumas'), ('lumia'), ('lunas'), ('lupas'), ('lupia'), ('lutea'),
                    ('luvia'), ('luzes'), ('macha'), ('macia'), ('macis'), ('madre'), ('maesa'), ('mafia'),
                    ('magia'), ('magra'), ('malas'), ('malla'), ('malta'), ('mamas'), ('manda'), ('manea'),
                    ('manga'), ('mania'), ('manes'), ('mañas'), ('marca'), ('marea'), ('marga'), ('maria'),
                    ('marra'), ('marta'), ('masas'), ('masia'), ('matas'), ('mayas'), ('mazas'), ('meaja'),
                    ('mecas'), ('mecha'), ('media'), ('medra'), ('melas'), ('melca'), ('mella'), ('melva'),
                    ('memez'), ('menas'), ('mente'), ('menta'), ('merca'), ('merla'), ('merma'), ('mesas'),
                    ('miaja'), ('micas'), ('micha'), ('micra'), ('miera'), ('migas'), ('milis'), ('milla'),
                    ('minas'), ('minga'), ('miras'), ('mirla'), ('mirra'), ('misas'), ('mitad'), ('mitas'),
                    ('mitra'), ('mizas'), ('mocha'), ('modas'), ('mofas'), ('moles'), ('molas'), ('molla'),
                    ('molsa'), ('momia'), ('monas'), ('monda'), ('monja'), ('monta'), ('moñas'), ('moral'),
                    ('morfa'), ('morga'), ('morra'), ('morsa'), ('mosca'), ('motas'), ('motos'), ('moxas'),
                    ('mozas'), ('mudas'), ('mueca'), ('muela'), ('muera'), ('mufla'), ('mugas'), ('mugre'),
                    ('mujer'), ('mulas'), ('multa'), ('murga'), ('murta'), ('musas'), ('mutas'), ('mutua'),
                    ('nabas'), ('nabla'), ('nafta'), ('nagua'), ('nalga'), ('nanas'), ('nansa'), ('napas'),
                    ('napea'), ('nares'), ('nariz'), ('nasas'), ('natas'), ('naves'), ('navas'), ('negra'),
                    ('nemas'), ('nenia'), ('niara'), ('nieve'), ('nigua'), ('ninfa'), ('niñas'), ('nipas'),
                    ('nocas'), ('noche'), ('nocla'), ('nomas'), ('nonas'), ('noria'), ('norma'), ('notas'),
                    ('noxas'), ('nubes'), ('nucas'), ('nuera'), ('nueva'), ('nueza'), ('nutra'), ('ñoñez'),
                    ('oblea'), ('obras'), ('ocena'), ('ofita'), ('oidas'), ('ojera'), ('ojiva'), ('ojota'),
                    ('oliva'), ('ollas'), ('omega'), ('ondas'), ('onice'), ('onzas'), ('opera'), ('orcas'),
                    ('oreas'), ('orgia'), ('orina'), ('orlas'), ('oruga'), ('osera'), ('ostia'), ('ostra'),
                    ('otoba'), ('oveja'), ('ozona'), ('pacas'), ('pagas'), ('paila'), ('pajas'), ('palas'),
                    ('palia'), ('palma'), ('panas'), ('panca'), ('panda'), ('panza'), ('papas'), ('parca'),
                    ('pared'), ('pares'), ('parla'), ('parra'), ('parva'), ('pasas'), ('pasma'), ('pasta'),
                    ('pausa'), ('pauta'), ('pavas'), ('pavia'), ('pazes'), ('peana'), ('pecas'), ('pegas'),
                    ('peina'), ('pelas'), ('pelea'), ('pella'), ('pelta'), ('penas'), ('penca'), ('peñas'),
                    ('pepas'), ('peras'), ('perca'), ('peris'), ('perla'), ('perna'), ('perra'), ('pesas'),
                    ('pesca'), ('peste'), ('piara'), ('picas'), ('picea'), ('pieza'), ('pilas'), ('pinas'),
                    ('pinna'), ('pinta'), ('pinza'), ('piñas'), ('piola'), ('pipas'), ('pirla'), ('pisas'),
                    ('pista'), ('pitas'), ('pizca'), ('pizza'), ('placa'), ('plaga'), ('plana'), ('plata'),
                    ('playa'), ('plaza'), ('plebe'), ('pleca'), ('plena'), ('plepa'), ('plica'), ('pluma'),
                    ('podas'), ('podre'), ('polca'), ('polea'), ('polis'), ('polla'), ('pomas'), ('pomez'),
                    ('pompa'), ('popas'), ('porta'), ('posas'), ('posca'), ('potra'), ('poyas'), ('pozas'),
                    ('presa'), ('prima'), ('prisa'), ('proas'), ('prole'), ('prora'), ('prosa'), ('pruna'),
                    ('psies'), ('pucia'), ('pugas'), ('pugna'), ('pujas'), ('pulga'), ('pulla'), ('pulpa'),
                    ('punas'), ('punta'), ('pupas'), ('purga'), ('putas'), ('puyas'), ('queda'), ('queja'),
                    ('quema'), ('quena'), ('quina'), ('quita'), ('rabas'), ('rabia'), ('racha'), ('racor'),
                    ('radas'), ('rafas'), ('rafia'), ('ragua'), ('rajas'), ('rampa'), ('ranas'), ('rañas'),
                    ('rapas'), ('rasas'), ('raspa'), ('ratio'), ('rauda'), ('rauta'), ('rayas'), ('razas'),
                    ('razon'), ('reata'), ('recta'), ('recua'), ('regla'), ('reina'), ('rejas'), ('renes'),
                    ('renta'), ('resta'), ('riada'), ('ricas'), ('ricia'), ('rifas'), ('rimas'), ('riñas'),
                    ('risas'), ('rizas'), ('robra'), ('rocas'), ('rodas'), ('rodea'), ('roela'), ('rojez'),
                    ('rolla'), ('ronca'), ('ropas'), ('rosas'), ('rosca'), ('rotas'), ('royas'), ('rozas'),
                    ('rubia'), ('rudas'), ('rueca'), ('rueda'), ('ruina'), ('rumia'), ('runas'), ('rupia'),
                    ('rutas'), ('sacas'), ('sacra'), ('saeta'), ('sagas'), ('salas'), ('salga'), ('sales'),
                    ('salma'), ('salpa'), ('salsa'), ('salud'), ('salva'), ('salve'), ('sanie'), ('santa'),
                    ('sañas'), ('sapas'), ('sarga'), ('sarna'), ('sarta'), ('sarza'), ('sauna'), ('savia'),
                    ('sayas'), ('sazon'), ('sebes'), ('secas'), ('secta'), ('sedes'), ('sedas'), ('segur'),
                    ('selva'), ('senas'), ('senda'), ('señas'), ('señal'), ('seras'), ('serba'), ('serie'),
                    ('serna'), ('serpa'), ('sesma'), ('setas'), ('sexta'), ('sidra'), ('siega'), ('sigla'),
                    ('sigma'), ('silba'), ('silla'), ('silva'), ('simas'), ('simia'), ('sirte'), ('sisas'),
                    ('sobas'), ('sobra'), ('sodas'), ('soeza'), ('sojas'), ('solfa'), ('solla'), ('somas'),
                    ('sonda'), ('sopas'), ('sorda'), ('sores'), ('soras'), ('sorna'), ('sorra'), ('sosas'),
                    ('sotas'), ('suela'), ('sufra'), ('suite'), ('sumas'), ('tabas'), ('tabes'), ('tabla'),
                    ('tacas'), ('tacha'), ('tafia'), ('tahas'), ('taifa'), ('taiga'), ('taina'), ('tajas'),
                    ('tajea'), ('talas'), ('talla'), ('talma'), ('talpa'), ('tanda'), ('tanga'), ('tapas'),
                    ('tapia'), ('taras'), ('tarde'), ('tarea'), ('tarja'), ('tarta'), ('tasas'), ('tasca'),
                    ('tazas'), ('tecas'), ('tecla'), ('tedas'), ('tejas'), ('telas'), ('teles'), ('tenas'),
                    ('tenca'), ('tenia'), ('terna'), ('tesis'), ('testa'), ('tetas'), ('tiaca'), ('tiara'),
                    ('tibia'), ('tijas'), ('tilas'), ('tilde'), ('tilia'), ('timba'), ('timpa'), ('tinas'),
                    ('tinta'), ('tiñas'), ('tipas'), ('tiras'), ('tisis'), ('tizas'), ('tizna'), ('tobas'),
                    ('tocas'), ('toesa'), ('togas'), ('tolla'), ('tolva'), ('tomas'), ('tonga'), ('topas'),
                    ('torce'), ('torca'), ('torga'), ('torna'), ('torre'), ('torta'), ('torva'), ('toses'),
                    ('tovas'), ('traba'), ('trabe'), ('traca'), ('trama'), ('trapa'), ('trata'), ('traza'),
                    ('treja'), ('trena'), ('treta'), ('trias'), ('tribu'), ('triga'), ('tripa'), ('troje'),
                    ('troja'), ('trola'), ('trona'), ('tropa'), ('trova'), ('truja'), ('tubas'), ('tucas'),
                    ('tudas'), ('tueca'), ('tuera'), ('tumba'), ('tunas'), ('tunda'), ('tupas'), ('turas'),
                    ('turba'), ('turma'), ('tutia'), ('tuyas'), ('ubres'), ('umbra'), ('uncia'), ('union'),
                    ('urbes'), ('ureas'), ('urnas'), ('uruga'), ('usura'), ('uvada'), ('uveas'), ('uvula'),
                    ('vacas'), ('vagas'), ('valia'), ('valla'), ('valva'), ('varas'), ('varea'), ('varga'),
                    ('variz'), ('vayas'), ('vedas'), ('vegas'), ('vejez'), ('velas'), ('venas'), ('venda'),
                    ('venia'), ('venta'), ('venus'), ('veras'), ('verba'), ('verja'), ('veste'), ('vetas'),
                    ('vezes'), ('viada'), ('vicia'), ('vides'), ('vidas'), ('vigas'), ('villa'), ('vinta'),
                    ('viñas'), ('viras'), ('vozes'), ('vulva'), ('yacas'), ('yagua'), ('yanta'), ('yarda'),
                    ('yedra'), ('yegua'), ('yemas'), ('yerba'), ('yesca'), ('yucas'), ('yunta'), ('zabra'),
                    ('zaina'), ('zalea'), ('zanca'), ('zanga'), ('zanja'), ('zapas'), ('zarja'), ('zarpa'),
                    ('zarza'), ('zatas'), ('zayas'), ('zedas'), ('zetas'), ('zofra'), ('zomas'), ('zorra'),
                    ('zubia'), ('zudas'), ('zuela'), ('zuiza'), ('zumba'), ('zurra'), ('azuas'), ('calla'),
                    ('chala'), ('huaca'), ('jabas'), ('joras'), ('oroya'), ('quila'), ('raras'), ('tigra'),
                    ('tolas'), ('yerra'), ('cholo'), ('futre'), ('guato'), ('huaco'), ('laque'), ('nacos'),
                    ('pucho'), ('quijo'), ('rubro'), ('sport'), ('tamal'), ('tambo'), ('tlaco'), ('tucos'),
                    ('video'), ('yuyos'), ('milpa'), ('mogos'), ('mogas'), ('biper'), ('bulon'), ('chile'),
                    ('comal'), ('olote'), ('paste'), ('tiste'), ('zocas'), ('maras'), ('cuate'), ('cuata'),
                    ('guiro'), ('guira'), ('biper'), ('cutos'), ('pinol'), ('pelis'), ('pacha'), ('bebes'),
                    ('bebas'), ('chavo'), ('chava'), ('cutas'), ('guate'), ('atole'), ('gofio'), ('nance'),
                    ('pegue'), ('sutes'), ('toles'), ('tunco'), ('tuyos'), ('zomos'), ('fisio'), ('jijas'),
                    ('abias'), ('alifa'), ('aloya'), ('ansas'), ('arcea'), ('ardas'), ('avica'), ('barza'),
                    ('birla'), ('canta'), ('carba'), ('corra'), ('dalla'), ('dogas'), ('dorna'), ('enzas'),
                    ('erias'), ('fabas'), ('fulla'), ('huera'), ('juera'), ('larra'), ('lefas'), ('lejas'),
                    ('llega'), ('llosa'), ('lomba'), ('lotas'), ('melsa'), ('metra'), ('morca'), ('narra'),
                    ('ocles'), ('pansa'), ('perta'), ('pocha'), ('quima'), ('riera'), ('rojal'), ('sansa'),
                    ('sisca'), ('sulas'), ('tabea'), ('vasas'), ('fatos'), ('fatas'), ('meigo'), ('meiga'),
                    ('nacho'), ('nacha'), ('cabal'), ('dance'), ('dujos'), ('eraje'), ('ferre'), ('foral'),
                    ('grelo'), ('homes'), ('hoves'), ('jorco'), ('jorro'), ('lamin'), ('lurte'), ('masto'),
                    ('mecos'), ('mires'), ('niazo'), ('pajuz'), ('rafal'), ('raijo'), ('redol'), ('ricio'),
                    ('rizon'), ('rosjo'), ('rungo'), ('rutel'), ('sanso'), ('sarde'), ('sarda'), ('seico'),
                    ('seles'), ('tocio'), ('torco'), ('torgo'), ('tumos'), ('video'), ('yebos'), ('zarbo'),
                    ('curul'), ('cuyas'), ('gripa'), ('juana'), ('julia'), ('nejas'), ('ñapas'), ('tilma'),
                    ('tunca'), ('guiro'), ('guira'), ('jolin'), ('manas'), ('nacas'), ('pocho'), ('ayate'),
                    ('biper'), ('desos'), ('perus'), ('sotol'), ('chuva'), ('teclo'), ('fonos'), ('sango'),
                    ('tipeo'), ('arepa'), ('bijas'), ('fleta'), ('guama'), ('lucas'), ('subas'), ('tagua'),
                    ('acabe'), ('fique'), ('hayos'), ('merey'), ('nemes'), ('nolis'), ('nolis'), ('olaje'),
                    ('sotes'), ('tefes'), ('tegua'), ('tibes'), ('toche'), ('tamba'), ('longo'), ('maton'),
                    ('biper'), ('lleve'), ('mames'), ('molon'), ('retro'), ('vales'), ('secua'), ('caney'),
                    ('copey'), ('ocumo'), ('urape'), ('mixta'), ('biper'), ('guayo'), ('pones'), ('pipes'),
                    ('biper'), ('facon'), ('teros'), ('timbo'), ('brava'), ('fumas'), ('rusia'), ('yabas'),
                    ('yanas'), ('abuje'), ('caico'), ('cuyas'), ('facho'), ('ocuje'), ('patao'), ('ronco'),
                    ('yales'), ('traga'), ('giles'), ('gilas'), ('bulon'), ('facon'), ('leuco'), ('ojito'),
                    ('rinde'), ('yatay'), ('machi'), ('huira'), ('nalca'), ('petra'), ('guaso'), ('mateo'),
                    ('matea'), ('biper'), ('coipo'), ('falte'), ('jotes'), ('linao'), ('nucos'), ('piure'),
                    ('sanco'), ('temus'), ('traro'), ('trebo'), ('yecos'), ('quedo'), ('ugres'), ('goyas'),
                    ('sampa'), ('biper'), ('bulon'), ('facon'), ('salar'), ('talar'), ('tarco'), ('tasis'),
                    ('timbo'), ('acnes'), ('agave'), ('agrio'), ('agria'), ('ajero'), ('ajera'), ('altos'),
                    ('amado'), ('amada'), ('amigo'), ('amiga'), ('ancho'), ('anexo'), ('anexa'), ('arios'),
                    ('aroma'), ('autor'), ('ayuda'), ('beato'), ('beata'), ('bedel'), ('bobos'), ('bobas'),
                    ('bombo'), ('botes'), ('braco'), ('braca'), ('breve'), ('brujo'), ('bruja'), ('bruto'),
                    ('bueno'), ('bufos'), ('bufon'), ('caido'), ('caida'), ('calor'), ('calvo'), ('cario'),
                    ('caria'), ('chapo'), ('chato'), ('chata'), ('checo'), ('checa'), ('chepa'), ('chico'),
                    ('chino'), ('chulo'), ('chula'), ('cisma'), ('claro'), ('color'), ('congo'), ('corso'),
                    ('corsa'), ('corvo'), ('crios'), ('crias'), ('curas'), ('cutis'), ('delta'), ('deudo'),
                    ('disco'), ('divos'), ('dotes'), ('edila'), ('enano'), ('enana'), ('epico'), ('epica'),
                    ('etico'), ('etica'), ('falso'), ('fenix'), ('fijos'), ('final'), ('frios'), ('frias'),
                    ('fusco'), ('fusca'), ('gafos'), ('gafas'), ('galgo'), ('galga'), ('galos'), ('godos'),
                    ('godas'), ('golfo'), ('gordo'), ('grifo'), ('guias'), ('guiro'), ('guira'), ('hijos'),
                    ('hijas'), ('hitos'), ('hitas'), ('honor'), ('impio'), ('impia'), ('indio'), ('india'),
                    ('ingas'), ('largo'), ('legos'), ('lisos'), ('lisas'), ('llano'), ('locos'), ('magro'),
                    ('malos'), ('malva'), ('mamon'), ('manas'), ('maños'), ('mapas'), ('mason'), ('mayor'),
                    ('medio'), ('medos'), ('medas'), ('memos'), ('memas'), ('menor'), ('metas'), ('misio'),
                    ('misia'), ('mocho'), ('monos'), ('moros'), ('moras'), ('motor'), ('mozos'), ('negro'),
                    ('nenes'), ('nenas'), ('nieto'), ('nieta'), ('niños'), ('novio'), ('novia'), ('overo'),
                    ('overa'), ('pampa'), ('pando'), ('parte'), ('pelon'), ('pijos'), ('pijas'), ('pillo'),
                    ('pilla'), ('pinto'), ('piona'), ('pivot'), ('plano'), ('pleno'), ('polio'), ('porra'),
                    ('posta'), ('primo'), ('profe'), ('profa'), ('quito'), ('randa'), ('rapaz'), ('rasos'),
                    ('recto'), ('ronda'), ('ruano'), ('ruana'), ('rubio'), ('runos'), ('rusos'), ('rusas'),
                    ('sabio'), ('sabia'), ('sacro'), ('sajon'), ('santo'), ('sapos'), ('sardo'), ('secos'),
                    ('señor'), ('seora'), ('sepia'), ('sesgo'), ('sesga'), ('sesmo'), ('sexmo'), ('sexma'),
                    ('sexto'), ('socio'), ('socia'), ('sogas'), ('sordo'), ('suizo'), ('suiza'), ('taino'),
                    ('temas'), ('tigre'), ('titos'), ('titas'), ('tordo'), ('torda'), ('tosco'), ('tosca'),
                    ('turco'), ('turca'), ('tutor'), ('uvero'), ('uvera'), ('vaina'), ('viejo'), ('vieja'),
                    ('virgo'), ('vista'), ('viudo'), ('viuda'), ('wifis'), ('yayos'), ('yayas'), ('zagal'),
                    ('zagas'), ('zambo'), ('zamba'), ('zocos'), ('zonas'), ('zurdo'), ('zurda'), ('alfoz'),
                    ('anade'), ('artes'), ('babel'), ('canal'), ('combi'), ('fines'), ('herpe'), ('lente'),
                    ('linde'), ('macro'), ('mares'), ('neuma'), ('orden'), ('pebre'), ('rafes'), ('reuma'),
                    ('tizne'), ('vodka'), ('abaca'), ('abaco'), ('abece'), ('abete'), ('abeto'), ('abiar'),
                    ('abril'), ('abuso'), ('acabo'), ('acaro'), ('acedo'), ('acial'), ('acido'), ('acilo'),
                    ('acles'), ('acres'), ('actor'), ('actos'), ('acure'), ('acuse'), ('ademe'), ('adios'),
                    ('adive'), ('adobe'), ('adobo'), ('adral'), ('aduar'), ('aedos'), ('aetas'), ('aforo'),
                    ('agape'), ('agnus'), ('agraz'), ('aguay'), ('agudo'), ('ahilo'), ('ahogo'), ('aires'),
                    ('airon'), ('ajeos'), ('ajete'), ('ajuar'), ('alabe'), ('alaju'), ('alamo'), ('alano'),
                    ('albar'), ('albor'), ('album'), ('albur'), ('alces'), ('alcor'), ('alece'), ('aleli'),
                    ('alelo'), ('alero'), ('aleto'), ('alezo'), ('alfar'), ('alfil'), ('alfiz'), ('algar'),
                    ('alias'), ('aliño'), ('aliso'), ('aljez'), ('almez'), ('almud'), ('aloes'), ('altar'),
                    ('alveo'), ('amago'), ('ambar'), ('ambos'), ('amelo'), ('ameos'), ('amibo'), ('amole'),
                    ('amuso'), ('anaco'), ('anafe'), ('anana'), ('andar'), ('anden'), ('anear'), ('anejo'),
                    ('angel'), ('animo'), ('anion'), ('anodo'), ('ansar'), ('antes'), ('antro'), ('aojos'),
                    ('apego'), ('apeos'), ('apice'), ('apios'), ('apodo'), ('apodo'), ('apolo'), ('aquel'),
                    ('arabo'), ('arado'), ('arbol'), ('arcen'), ('arces'), ('arcon'), ('arcos'), ('ardid'),
                    ('ardor'), ('arete'), ('argen'), ('argon'), ('argos'), ('argot'), ('arido'), ('arnes'),
                    ('aromo'), ('arpeo'), ('arpon'), ('arreo'), ('arres'), ('arroz'), ('arzon'), ('asado'),
                    ('asana'), ('asaro'), ('ascos'), ('aseos'), ('asnos'), ('aspid'), ('aspro'), ('aster'),
                    ('astil'), ('astro'), ('atabe'), ('atado'), ('ataud'), ('atico'), ('atlas'), ('atomo'),
                    ('atril'), ('atrio'), ('audio'), ('auges'), ('augur'), ('aureo'), ('autos'), ('avion'),
                    ('avios'), ('aviso'), ('avugo'), ('ayuno'), ('azoes'), ('azote'), ('babis'), ('bable'),
                    ('babor'), ('bache'), ('bacin'), ('badal'), ('badan'), ('baden'), ('badil'), ('bagre'),
                    ('baile'), ('bajas'), ('bajel'), ('bajio'), ('bajon'), ('bajos'), ('balaj'), ('balay'),
                    ('balin'), ('balon'), ('balso'), ('bambu'), ('bance'), ('banco'), ('bando'), ('banzo'),
                    ('baños'), ('baque'), ('barbo'), ('barco'), ('bario'), ('baron'), ('baros'), ('barro'),
                    ('bares'), ('basto'), ('batan'), ('bates'), ('batel'), ('batos'), ('bayal'), ('bayos'),
                    ('bazar'), ('bazos'), ('bebes'), ('befos'), ('bejin'), ('belen'), ('belez'), ('belfo'),
                    ('belio'), ('beles'), ('bemol'), ('benes'), ('berro'), ('beses'), ('besos'), ('betel'),
                    ('betun'), ('beyes'), ('bezar'), ('bicho'), ('bides'), ('bidon'), ('bilao'), ('bingo'),
                    ('birlo'), ('bisel'), ('bites'), ('bledo'), ('blues'), ('boato'), ('bocal'), ('bocel'),
                    ('bocin'), ('bocio'), ('bodes'), ('bofes'), ('bojeo'), ('bojes'), ('boldo'), ('boles'),
                    ('bolin'), ('bollo'), ('bolso'), ('bongo'), ('bonos'), ('bonus'), ('bonzo'), ('borax'),
                    ('borde'), ('bordo'), ('borni'), ('boros'), ('boson'), ('botin'), ('botos'), ('boton'),
                    ('botox'), ('boxeo'), ('boxer'), ('bozos'), ('bravo'), ('brazo'), ('brete'), ('brezo'),
                    ('brial'), ('bromo'), ('brote'), ('brugo'), ('bruno'), ('buaro'), ('bubon'), ('buceo'),
                    ('buche'), ('bucle'), ('bucos'), ('budin'), ('bufon'), ('bugle'), ('buhos'), ('bujes'),
                    ('bulbo'), ('bulos'), ('bulto'), ('buque'), ('bureo'), ('buril'), ('buris'), ('burro'),
                    ('buses'), ('busto'), ('buyos'), ('buzon'), ('bytes'), ('cabes'), ('cable'), ('cacho'),
                    ('cacos'), ('cacto'), ('cadas'), ('cadis'), ('cafes'), ('cajon'), ('calar'), ('calco'),
                    ('caldo'), ('caliz'), ('callo'), ('calos'), ('cameo'), ('camon'), ('campo'), ('canje'),
                    ('canon'), ('canes'), ('cante'), ('canto'), ('cañar'), ('cañon'), ('caños'), ('capon'),
                    ('capos'), ('capuz'), ('caqui'), ('caray'), ('cardo'), ('cares'), ('careo'), ('carey'),
                    ('cargo'), ('cariz'), ('carne'), ('carpo'), ('carro'), ('casal'), ('casar'), ('casco'),
                    ('cases'), ('casos'), ('caton'), ('catos'), ('catre'), ('cauce'), ('cauro'), ('cavos'),
                    ('cayos'), ('cazon'), ('cazos'), ('cazes'), ('cazuz'), ('cebos'), ('cebon'), ('cedro'),
                    ('cefos'), ('celos'), ('celta'), ('cenit'), ('censo'), ('ceños'), ('cepos'), ('cequi'),
                    ('cerco'), ('cerdo'), ('cerio'), ('cerne'), ('cerno'), ('ceros'), ('cerro'), ('cesar'),
                    ('ceses'), ('cesio'), ('cesto'), ('cetro'), ('ceuti'), ('chaco'), ('chaco'), ('chale'),
                    ('chavo'), ('chist'), ('chito'), ('chivo'), ('choco'), ('chopo'), ('chori'), ('choto'),
                    ('chozo'), ('chute'), ('chuzo'), ('ciani'), ('ciclo'), ('cidro'), ('cides'), ('ciego'),
                    ('cielo'), ('cieno'), ('cilio'), ('cinco'), ('cines'), ('cinto'), ('cipos'), ('circo'),
                    ('cirio'), ('cirro'), ('cisco'), ('cisne'), ('civil'), ('clavo'), ('clero'), ('clima'),
                    ('clise'), ('cloro'), ('clubs'), ('coati'), ('cobre'), ('cobro'), ('coche'), ('cocho'),
                    ('cocos'), ('codal'), ('codos'), ('cofre'), ('coime'), ('coito'), ('cojin'), ('colin'),
                    ('colmo'), ('colon'), ('comic'), ('conde'), ('conos'), ('coñac'), ('coños'), ('copon'),
                    ('copos'), ('copto'), ('coque'), ('corea'), ('corps'), ('corro'), ('corse'), ('corto'),
                    ('corzo'), ('cosos'), ('coste'), ('costo'), ('cotos'), ('coxis'), ('crack'), ('craso'),
                    ('credo'), ('cribo'), ('cromo'), ('crono'), ('cross'), ('cruce'), ('cuajo'), ('cuark'),
                    ('cubil'), ('cubos'), ('cucos'), ('cuero'), ('cuezo'), ('culos'), ('culto'), ('cuños'),
                    ('cupes'), ('cupon'), ('cupos'), ('curie'), ('curio'), ('curro'), ('curry'), ('curso'),
                    ('cuzco'), ('dados'), ('dador'), ('dalle'), ('dandi'), ('danes'), ('danes'), ('dante'),
                    ('daños'), ('dardo'), ('datil'), ('datos'), ('deber'), ('debut'), ('decir'), ('dedal'),
                    ('dedil'), ('dejos'), ('deles'), ('deseo'), ('deses'), ('dicho'), ('diego'), ('dinar'),
                    ('diodo'), ('dique'), ('divan'), ('dixes'), ('doces'), ('dogal'), ('dogma'), ('dogos'),
                    ('dogre'), ('dolar'), ('dolor'), ('dolos'), ('dombo'), ('dones'), ('doral'), ('dorso'),
                    ('dosel'), ('doses'), ('drago'), ('drama'), ('drino'), ('drope'), ('dubio'), ('duelo'),
                    ('dueño'), ('dueto'), ('dulce'), ('duque'), ('duros'), ('ebano'), ('echos'), ('edema'),
                    ('efebo'), ('ejido'), ('elche'), ('elfos'), ('ellos'), ('elote'), ('eneal'), ('enema'),
                    ('enero'), ('ensay'), ('entes'), ('enves'), ('envio'), ('erbio'), ('erebo'), ('ergio'),
                    ('erizo'), ('erraj'), ('error'), ('escay'), ('esmog'), ('espay'), ('espin'), ('esqui'),
                    ('estay'), ('ester'), ('ester'), ('estio'), ('estro'), ('etano'), ('etilo'), ('euros'),
                    ('exito'), ('exodo'), ('facto'), ('fados'), ('fagos'), ('fajin'), ('fallo'), ('falos'),
                    ('fanal'), ('fango'), ('fanos'), ('farad'), ('fardo'), ('fario'), ('farol'), ('faros'),
                    ('farro'), ('fasto'), ('fauno'), ('favor'), ('faxes'), ('femur'), ('ferro'), ('ferry'),
                    ('fetos'), ('feudo'), ('ficus'), ('fideo'), ('fiero'), ('figon'), ('figos'), ('filme'),
                    ('filon'), ('filos'), ('fines'), ('finos'), ('fines'), ('firme'), ('fisco'), ('fitos'),
                    ('flaco'), ('flash'), ('flato'), ('fleco'), ('fleje'), ('flete'), ('flexo'), ('flojo'),
                    ('flote'), ('flujo'), ('fluor'), ('focos'), ('fogon'), ('folgo'), ('folio'), ('fondo'),
                    ('fonio'), ('foque'), ('foros'), ('forro'), ('fosar'), ('fosil'), ('fosos'), ('foton'),
                    ('freno'), ('freos'), ('frior'), ('friso'), ('frito'), ('frote'), ('fruto'), ('fucos'),
                    ('fuego'), ('fuero'), ('fular'), ('fumos'), ('fundo'), ('furor'), ('furos'), ('fusil'),
                    ('fusor'), ('fuste'), ('gaban'), ('gacel'), ('gacho'), ('gajes'), ('gajos'), ('galan'),
                    ('gales'), ('galio'), ('gallo'), ('gales'), ('galon'), ('gamos'), ('ganso'), ('gante'),
                    ('gañan'), ('garbo'), ('garzo'), ('gases'), ('gasto'), ('gatos'), ('geles'), ('genes'),
                    ('genio'), ('gesto'), ('gines'), ('giros'), ('gises'), ('glase'), ('globo'), ('gluon'),
                    ('gneis'), ('gnomo'), ('gobio'), ('goces'), ('gocho'), ('golpe'), ('goles'), ('gonce'),
                    ('gorro'), ('goteo'), ('gozne'), ('gozos'), ('grado'), ('grafo'), ('grais'), ('grajo'),
                    ('gramo'), ('grano'), ('graos'), ('graso'), ('green'), ('grisu'), ('grito'), ('grumo'),
                    ('grupo'), ('guaco'), ('guaje'), ('guamo'), ('guano'), ('guapo'), ('gueto'), ('guijo'),
                    ('guiño'), ('guion'), ('guiso'), ('gules'), ('guros'), ('gusto'), ('habar'), ('haber'),
                    ('habiz'), ('habon'), ('hacho'), ('hados'), ('hafiz'), ('halls'), ('halos'), ('hampo'),
                    ('hanzo'), ('harem'), ('haren'), ('hatos'), ('haute'), ('havos'), ('hayal'), ('hecho'),
                    ('hedor'), ('helio'), ('helor'), ('henal'), ('henar'), ('henil'), ('henos'), ('henry'),
                    ('herma'), ('heroe'), ('hertz'), ('hiato'), ('hielo'), ('higos'), ('hilos'), ('himen'),
                    ('himno'), ('hindi'), ('hipos'), ('hirco'), ('hiyab'), ('hobby'), ('hobos'), ('hogar'),
                    ('holco'), ('hondo'), ('hongo'), ('hoque'), ('horco'), ('horno'), ('hoste'), ('hotel'),
                    ('hotos'), ('hoyos'), ('hueco'), ('hueso'), ('huevo'), ('huiro'), ('hules'), ('humos'),
                    ('humor'), ('humus'), ('huron'), ('hurto'), ('husmo'), ('husos'), ('icaco'), ('ichal'),
                    ('ichos'), ('ichus'), ('icono'), ('icono'), ('ideal'), ('idolo'), ('iglus'), ('igual'),
                    ('ileon'), ('ilion'), ('impar'), ('inris'), ('invar'), ('iones'), ('islam'), ('istmo'),
                    ('items'), ('itrio'), ('izote'), ('jabis'), ('jabon'), ('jacos'), ('jadeo'), ('jades'),
                    ('jaleo'), ('jalon'), ('jamon'), ('jaque'), ('jaral'), ('jaros'), ('jarro'), ('jaspe'),
                    ('jateo'), ('jatib'), ('jatos'), ('jebes'), ('jeito'), ('jeliz'), ('jemes'), ('jeque'),
                    ('jerbo'), ('jerez'), ('jimio'), ('jiron'), ('jobos'), ('jofor'), ('jorfe'), ('jorge'),
                    ('joule'), ('joyel'), ('joyos'), ('jubon'), ('jubos'), ('judas'), ('juego'), ('jugos'),
                    ('julio'), ('julos'), ('junco'), ('junio'), ('jurel'), ('juros'), ('jusis'), ('kakis'),
                    ('kanes'), ('karma'), ('kilos'), ('kirie'), ('kites'), ('labio'), ('lacon'), ('lacre'),
                    ('lados'), ('lagar'), ('lagos'), ('lance'), ('lapiz'), ('lapon'), ('lapos'), ('lapso'),
                    ('lardo'), ('lares'), ('laser'), ('lataz'), ('latex'), ('latin'), ('laton'), ('laudo'),
                    ('lauro'), ('laves'), ('lazos'), ('lecho'), ('ledes'), ('leima'), ('lejos'), ('lemas'),
                    ('lembo'), ('lemes'), ('lenca'), ('lento'), ('leños'), ('leste'), ('liber'), ('libro'),
                    ('liceo'), ('licor'), ('lilao'), ('limbo'), ('limen'), ('limos'), ('limon'), ('linar'),
                    ('lince'), ('lindo'), ('linio'), ('linos'), ('lirio'), ('liron'), ('litio'), ('litre'),
                    ('litro'), ('lituo'), ('livor'), ('lizos'), ('lleno'), ('lloro'), ('lobos'), ('local'),
                    ('loche'), ('locro'), ('lodos'), ('logar'), ('logos'), ('logro'), ('lombo'), ('lomos'),
                    ('lores'), ('loros'), ('lotes'), ('lotos'), ('lucio'), ('lucro'), ('lugar'), ('lugre'),
                    ('lujos'), ('lulus'), ('lumbo'), ('lumen'), ('lunar'), ('lunes'), ('lupus'), ('lutos'),
                    ('luxes'), ('macho'), ('mador'), ('maese'), ('magma'), ('magos'), ('majal'), ('malar'),
                    ('mallo'), ('males'), ('mambo'), ('mamey'), ('mamut'), ('manco'), ('mando'), ('mango'),
                    ('manso'), ('manto'), ('maqui'), ('marco'), ('mareo'), ('maros'), ('maron'), ('marro'),
                    ('marte'), ('marzo'), ('maslo'), ('mason'), ('mases'), ('mates'), ('matiz'), ('maton'),
                    ('maure'), ('mayal'), ('mayos'), ('mazos'), ('meado'), ('meato'), ('medro'), ('melis'),
                    ('melon'), ('menos'), ('menus'), ('mergo'), ('merlo'), ('meros'), ('meses'), ('meson'),
                    ('mesto'), ('metal'), ('metro'), ('micer'), ('micho'), ('micos'), ('micro'), ('miedo'),
                    ('mijos'), ('milan'), ('millo'), ('miles'), ('mimos'), ('mingo'), ('minio'), ('minue'),
                    ('mioma'), ('mirlo'), ('mirto'), ('mirza'), ('misal'), ('misil'), ('mitin'), ('mitos'),
                    ('miton'), ('mixto'), ('mizos'), ('mizes'), ('moare'), ('mocos'), ('mocas'), ('modal'),
                    ('modem'), ('modio'), ('modos'), ('mohos'), ('mojel'), ('mojes'), ('mojis'), ('mojon'),
                    ('mojos'), ('molar'), ('molde'), ('molle'), ('momio'), ('momos'), ('mongo'), ('monje'),
                    ('monte'), ('moños'), ('morbo'), ('morfo'), ('morro'), ('morse'), ('mosco'), ('mosto'),
                    ('motel'), ('motes'), ('motil'), ('motin'), ('moton'), ('movil'), ('moyos'), ('moyas'),
                    ('muare'), ('mudar'), ('mugor'), ('mujol'), ('muleo'), ('mulos'), ('mundo'), ('muñon'),
                    ('mural'), ('muria'), ('mures'), ('muros'), ('musco'), ('museo'), ('musgo'), ('muslo'),
                    ('muses'), ('mutis'), ('mutuo'), ('nabab'), ('nabar'), ('nabos'), ('nacar'), ('nacre'),
                    ('nadie'), ('nadir'), ('naife'), ('naipe'), ('naire'), ('naque'), ('nardo'), ('nasos'),
                    ('natal'), ('nauta'), ('naval'), ('navio'), ('nebli'), ('negus'), ('neldo'), ('neron'),
                    ('netos'), ('nexos'), ('nicho'), ('nicle'), ('nicol'), ('nidal'), ('nidos'), ('ninfo'),
                    ('ninja'), ('nioto'), ('nitos'), ('nitro'), ('nivel'), ('noble'), ('nodos'), ('nogal'),
                    ('nomon'), ('nomos'), ('nonio'), ('nopal'), ('noray'), ('norte'), ('notos'), ('notro'),
                    ('nubio'), ('nublo'), ('nudos'), ('nueve'), ('numen'), ('numos'), ('ñames'), ('ñandu'),
                    ('ñaque'), ('oasis'), ('obice'), ('obito'), ('obron'), ('ocaso'), ('ocelo'), ('ochos'),
                    ('ocios'), ('ocres'), ('odeon'), ('odios'), ('odres'), ('oeste'), ('ogros'), ('ohmio'),
                    ('oidio'), ('oidor'), ('oidos'), ('ojeos'), ('ojete'), ('oleos'), ('olios'), ('olivo'),
                    ('ollao'), ('olmos'), ('ombus'), ('omero'), ('onces'), ('opalo'), ('opios'), ('orbes'),
                    ('orcos'), ('orfos'), ('orfre'), ('oribe'), ('orive'), ('orsay'), ('ortos'), ('orujo'),
                    ('oscos'), ('osero'), ('osmio'), ('ostro'), ('otero'), ('otoño'), ('ovalo'), ('ovino'),
                    ('ovnis'), ('ovulo'), ('oxido'), ('ozono'), ('pacay'), ('pacto'), ('padre'), ('pagel'),
                    ('pagos'), ('pagro'), ('paico'), ('pajar'), ('pajel'), ('pajos'), ('palco'), ('pales'),
                    ('palio'), ('palmo'), ('palos'), ('panal'), ('panco'), ('panel'), ('panes'), ('panos'),
                    ('pañal'), ('pañol'), ('paños'), ('papas'), ('papel'), ('papos'), ('parar'), ('parce'),
                    ('parco'), ('pardo'), ('pargo'), ('paros'), ('parto'), ('pases'), ('paseo'), ('pasmo'),
                    ('pasos'), ('pasto'), ('patan'), ('pates'), ('patin'), ('patio'), ('patos'), ('paves'),
                    ('pavon'), ('pavor'), ('pavos'), ('payos'), ('pazos'), ('peaje'), ('pecho'), ('pecio'),
                    ('pedal'), ('pedos'), ('pedro'), ('pegos'), ('peine'), ('pejes'), ('pello'), ('pelos'),
                    ('penal'), ('penco'), ('penes'), ('penol'), ('peñon'), ('pepes'), ('peplo'), ('peral'),
                    ('perno'), ('peros'), ('perol'), ('perro'), ('persa'), ('pesar'), ('pesos'), ('petos'),
                    ('pezon'), ('pezes'), ('piano'), ('piche'), ('pichi'), ('picon'), ('picor'), ('picos'),
                    ('piejo'), ('pilar'), ('pilon'), ('pinar'), ('pinos'), ('pines'), ('piñon'), ('piojo'),
                    ('pipis'), ('pique'), ('piros'), ('pisco'), ('pisos'), ('pisto'), ('pitao'), ('pitos'),
                    ('piton'), ('piune'), ('pixel'), ('pixel'), ('plato'), ('plato'), ('playo'), ('pleon'),
                    ('plexo'), ('plomo'), ('pobos'), ('pocos'), ('poder'), ('podio'), ('podon'), ('poema'),
                    ('polen'), ('poleo'), ('pollo'), ('polos'), ('polvo'), ('pomar'), ('pomos'), ('poney'),
                    ('ponis'), ('ponto'), ('porno'), ('poros'), ('porro'), ('porte'), ('poson'), ('posos'),
                    ('poses'), ('poste'), ('potes'), ('potro'), ('poyos'), ('pozos'), ('prado'), ('prest'),
                    ('prion'), ('prior'), ('pruno'), ('pubes'), ('pubis'), ('pudin'), ('pudor'), ('pufos'),
                    ('pugil'), ('pulpo'), ('pulso'), ('pumas'), ('punto'), ('punzo'), ('puñal'), ('puños'),
                    ('pures'), ('puros'), ('putos'), ('puton'), ('puzol'), ('quera'), ('queso'), ('quilo'),
                    ('quimo'), ('quino'), ('rabal'), ('rabel'), ('rabis'), ('rabos'), ('radar'), ('radon'),
                    ('rallo'), ('ramal'), ('ramio'), ('ramos'), ('ramon'), ('rango'), ('ranos'), ('raños'),
                    ('rapes'), ('rapes'), ('rapto'), ('raque'), ('rases'), ('rasgo'), ('raton'), ('ratos'),
                    ('rayon'), ('rayos'), ('recre'), ('redil'), ('redor'), ('redro'), ('rehen'), ('reino'),
                    ('rejon'), ('rejos'), ('relax'), ('reles'), ('relej'), ('reloj'), ('remos'), ('renos'),
                    ('resto'), ('retal'), ('retel'), ('reten'), ('retor'), ('retos'), ('reves'), ('reyes'),
                    ('rezno'), ('rezon'), ('rezos'), ('riego'), ('rifle'), ('rigor'), ('riñon'), ('rioja'),
                    ('ripio'), ('risos'), ('ritmo'), ('ritos'), ('rizos'), ('roble'), ('robos'), ('robot'),
                    ('robre'), ('roces'), ('rocin'), ('rocio'), ('rodal'), ('rodeo'), ('rodio'), ('roete'),
                    ('rolde'), ('roleo'), ('rollo'), ('roles'), ('roman'), ('rombo'), ('ronce'), ('rones'),
                    ('ropon'), ('roque'), ('rorro'), ('rosal'), ('roses'), ('rotos'), ('rotor'), ('rouge'),
                    ('rubin'), ('rubis'), ('rublo'), ('rubor'), ('rubos'), ('ruedo'), ('ruego'), ('ruejo'),
                    ('rufos'), ('rugby'), ('ruido'), ('rulos'), ('rumbo'), ('rumor'), ('rumos'), ('rusco'),
                    ('saber'), ('sable'), ('sabor'), ('sabre'), ('sacos'), ('sacre'), ('saino'), ('salce'),
                    ('saldo'), ('salep'), ('salio'), ('salmo'), ('salol'), ('salon'), ('salto'), ('samas'),
                    ('saque'), ('sarao'), ('sargo'), ('sarro'), ('sarzo'), ('saten'), ('satis'), ('satos'),
                    ('sauce'), ('sauco'), ('sayal'), ('sayos'), ('sayon'), ('sazes'), ('sebos'), ('sedal'),
                    ('sedan'), ('segas'), ('seise'), ('sello'), ('semen'), ('semis'), ('senos'), ('senes'),
                    ('seres'), ('seron'), ('servo'), ('sesen'), ('seseo'), ('sesos'), ('setos'), ('setes'),
                    ('sexos'), ('sexys'), ('sibil'), ('siclo'), ('sidas'), ('siena'), ('sieso'), ('siete'),
                    ('sifon'), ('siglo'), ('signo'), ('silbo'), ('silex'), ('silfo'), ('silos'), ('siles'),
                    ('simil'), ('simio'), ('simon'), ('sinos'), ('sirle'), ('sismo'), ('sison'), ('sitio'),
                    ('sobeo'), ('sobre'), ('socaz'), ('sodio'), ('sofas'), ('sogun'), ('solar'), ('solaz'),
                    ('soler'), ('solio'), ('solos'), ('soles'), ('somos'), ('sones'), ('soplo'), ('sopor'),
                    ('sorbo'), ('sorce'), ('sorgo'), ('soros'), ('sosar'), ('sosia'), ('sotos'), ('stand'),
                    ('sudor'), ('suelo'), ('sueno'), ('sueño'), ('suero'), ('sumos'), ('surco'), ('susto'),
                    ('tabor'), ('tabus'), ('tacho'), ('tacon'), ('tacos'), ('tacto'), ('tafos'), ('tahur'),
                    ('tajon'), ('tajos'), ('talco'), ('talio'), ('talle'), ('tallo'), ('talos'), ('talon'),
                    ('talud'), ('tamil'), ('tamiz'), ('tamos'), ('tango'), ('tanto'), ('tapir'), ('tapis'),
                    ('tapiz'), ('tapon'), ('taque'), ('taque'), ('taray'), ('tarro'), ('tarso'), ('tasto'),
                    ('tatos'), ('taxis'), ('taxon'), ('tazon'), ('tebeo'), ('techo'), ('tecle'), ('tedio'),
                    ('tejar'), ('tejos'), ('tejon'), ('telar'), ('tells'), ('telon'), ('temor'), ('tempo'),
                    ('tenis'), ('tenor'), ('tepes'), ('termo'), ('terno'), ('tesla'), ('teson'), ('tesos'),
                    ('teton'), ('texto'), ('tices'), ('tifos'), ('tifus'), ('tilos'), ('timol'), ('timon'),
                    ('timos'), ('tinge'), ('tinos'), ('tinte'), ('tinto'), ('tipos'), ('tique'), ('tiron'),
                    ('tiros'), ('tirso'), ('tizon'), ('tizos'), ('tobar'), ('tocho'), ('tocon'), ('todos'),
                    ('tofos'), ('tojal'), ('tojos'), ('toldo'), ('tollo'), ('tolmo'), ('tomin'), ('tomos'),
                    ('tondo'), ('tonel'), ('toner'), ('tongo'), ('tonos'), ('tones'), ('tonto'), ('topos'),
                    ('toque'), ('toral'), ('torax'), ('toreo'), ('toril'), ('torio'), ('tormo'), ('torno'),
                    ('toros'), ('torso'), ('total'), ('totem'), ('tours'), ('tozos'), ('trago'), ('traje'),
                    ('tramo'), ('trape'), ('trapo'), ('trato'), ('trazo'), ('trece'), ('tremo'), ('treno'),
                    ('treos'), ('trial'), ('trigo'), ('trile'), ('trino'), ('trios'), ('tripe'), ('trole'),
                    ('trono'), ('tropo'), ('trote'), ('trozo'), ('truco'), ('trues'), ('trues'), ('tubos'),
                    ('tudel'), ('tueco'), ('tufos'), ('tulio'), ('tules'), ('tumbo'), ('tumor'), ('tunel'),
                    ('tupes'), ('tupis'), ('turbo'), ('turno'), ('tutes'), ('ubios'), ('ucase'), ('ujier'),
                    ('ulema'), ('umero'), ('untos'), ('uñero'), ('urato'), ('usier'), ('utero'), ('vacio'),
                    ('vacuo'), ('vades'), ('vados'), ('vagar'), ('vagos'), ('vagon'), ('vahos'), ('valer'),
                    ('valle'), ('valor'), ('vanos'), ('vapor'), ('varal'), ('vareo'), ('vario'), ('varon'),
                    ('vasar'), ('vasco'), ('vasos'), ('vater'), ('vates'), ('vatio'), ('vello'), ('velos'),
                    ('velon'), ('vendi'), ('vendo'), ('verbo'), ('verde'), ('veril'), ('verme'), ('vermu'),
                    ('veros'), ('veres'), ('vetos'), ('viaje'), ('vicio'), ('victo'), ('vigor'), ('vinco'),
                    ('vinos'), ('viril'), ('virus'), ('visco'), ('visir'), ('visos'), ('visor'), ('visto'),
                    ('vitor'), ('vitre'), ('vivac'), ('vivar'), ('vivir'), ('vivos'), ('voila'), ('volvo'),
                    ('votos'), ('vudus'), ('vuelo'), ('vulgo'), ('weber'), ('xenon'), ('yacio'), ('yakes'),
                    ('yambo'), ('yates'), ('yelmo'), ('yenes'), ('yermo'), ('yerno'), ('yeros'), ('yerro'),
                    ('yervo'), ('yesar'), ('yesos'), ('yezgo'), ('yodos'), ('yogur'), ('yugos'), ('yutes'),
                    ('zahon'), ('zanco'), ('zaque'), ('zares'), ('zarzo'), ('zenit'), ('zoizo'), ('zorro'),
                    ('zuavo'), ('zueco'), ('zumos'), ('zuros'), ('cheve'), ('ficho'), ('chias'), ('areta'),
                    ('cicla'), ('polas'), ('uneño'), ('uneña'), ('herpo'), ('jurgo'), ('mouse'), ('arche'),
                    ('memes'), ('swing'), ('titan'), ('video');
                """
            )
